
flt
===

**fast Legendre transform**

This is a minimal Python package for fast discrete Legendre transforms (DLTs).
The implementation uses a recursive version of the matrix relations by Alpert &
Rokhlin (1991) to compute the DLT via a discrete cosine transform (DCT).

The package can be installed using pip:

    pip install flt

For more information, please see the [documentation].

Current functionality covers the absolutely minimal use case.  Please open an
issue on GitHub if you would like to see anything added.

[documentation]: https://cltools.readthedocs.io/flt/
